# Tracking & Proxy API

## Tracking

::: pymotion.tracking.MotionTracker
::: pymotion.tracking.StabilizedClip

## Proxy

::: pymotion.proxy.ProxyClip
::: pymotion.proxy.create_proxy
::: pymotion.proxy.clear_proxy_cache
::: pymotion.proxy.proxy_cache_size
